import { csv } from 'd3';
import {
  select,
  json,
  pie,
  arc,
  scaleOrdinal,
  format
} from 'd3';

// Colors for the sections in Pie Chart
const sectionColors = [
  		'aqua', 'turquoise', 'lime', 'orange', 'green', 'skyblue', 'crimson', 'wheat', 'turquoise', 'orange'
		  ];

// Data set URL
const csvUrl = 'https://gist.githubusercontent.com/17761A04F1/f401b448846fcf92156b7cd7f1d0fe8c/raw/82edb39e34078293de6d577d33ce32de97a8710d/data.csv';

// Getting the data from the URL
const fetchData = async () => {
  const data = await csv(csvUrl);
  return data;
};

// Selecting the SVG in the HTML
const svg = select("svg");
const width = + svg.attr('width');
const height = + svg.attr('height');

// Formating the text on axes
const xAxisTickFormat = number =>
  	format('.4~g')(number);

// Rendering Pie Chart
const render = (data, total) => {
  const pieData = pie().value(d=>d.Deaths)(data);
  const colors = scaleOrdinal()
  	.domain(data)
  	.range(sectionColors);
  
  // Object for generating Arcs of the sections
  const arcGenerator = d3.arc()
  .innerRadius(0)
  .outerRadius(250);

  // Segments are the partition in the Pie Chart
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(175)
  	.padAngle(0)
  	.padRadius(0);
  
  const sections = svg.append("g")
  	.attr("transform", `translate(250,250)`)
  	.selectAll("path").data(pieData);
  
  sections.enter()
    .append("path")
    .attr("d", segments)
  	.attr("fill", d => colors(d.data.Deaths));
  
  // Render text on each section
  sections
    .enter()
    .append('text')
    .text(d => xAxisTickFormat((d.data.Deaths/1000))+"K")
    .attr("transform", function(d) { return "translate(" + arcGenerator.centroid(d) + ")";  })
    .style("text-anchor", "middle")
  	.style('fill', 'black')
    .style("font-size", 15);
  
  // Render legend for the data
  const legends = svg.append("g")
  	.attr("transform", "translate(500,100)")
    .selectAll(".legends").data(pieData);
  
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });
  
  // legend
  legend.append("rect").attr("width",20).attr("height",20)
  	.attr("fill", d => colors(d.data.Deaths));
  
  legend.append("text")
  	.attr("x", 250)
  	.attr("y", 15)
  	.attr("class","legend_value")
  	.text(d=>xAxisTickFormat((d.data.Deaths/1000))+"K");
  
  // Countries legend 
  legend.append("text")
  	.attr("x", 25)
  	.attr("y", 15)
  	.attr("class","legend_text")
  	.text(d => d.data.Country);
  
}

const run = async () => {
  let data = await fetchData()
  let total = 0
  data.forEach(d=>{
    d.Deaths = +d.Deaths;
    total += d.Deaths
  });
	render(data,total);
};
run();